import sys
from typing import Any, List

import click

from src.excel import write_xlsx


def main() -> None:
    sys.exit(cli())


@click.command()
@click.argument("template_xlsx", required=True, type=click.Path(exists=True))
@click.option(
    "--sheet_xy_csv",
    "-T",
    required=True,
    nargs=3,
    type=click.Tuple([int, str, click.Path(exists=True)]),
    multiple=True,
    help=("Sheet No and Address(ex: a1, aa12) and Input CSV file"),
)
@click.argument("output_xlsx", required=True, type=click.Path(writable=True))
@click.option("--delimiter", default=",", type=str, help="csv delimiter")
def cli(
    template_xlsx: str,
    sheet_xy_csv: List[Any],
    output_xlsx: str,
    delimiter: str,
) -> None:
    write_xlsx(template_xlsx, sheet_xy_csv, output_xlsx, delimiter)


if __name__ == "__main__":
    main()



import csv
from typing import Any, List

from openpyxl import load_workbook, worksheet
from openpyxl.utils.cell import (
    column_index_from_string, coordinate_from_string
)


def write_xlsx(
    template_xlsx: str,
    sheet_xy_csv: List[Any],
    output_xlsx: str,
    delimiter=",",
):
    """Xlsxファイルへの書き込みを行う

    Args:
        template_xlsx (str): 入力Xlsxファイル名
        sheet_xy_csv (List[Any]): シートNo + セル位置 ＋ 入力ファイル
        output_xlsx (str): 出力Xlsxファイル名
    """
    wb = load_workbook(filename=template_xlsx)

    for sheet_no, address, input_file in sheet_xy_csv:
        with open(input_file) as f:
            reader = csv.reader(f, delimiter=delimiter)
            input_csv = [row for row in reader]
            ws = wb.worksheets[sheet_no - 1]
            start_col_letter, start_row = coordinate_from_string(address)
            start_col = column_index_from_string(start_col_letter)
            write_list_2d(ws, input_csv, start_row, start_col)

    wb.save(output_xlsx)


def write_list_2d(
    sheet: worksheet, l_2d: List[List[str]], start_row: int, start_col: int,
) -> None:
    """2次元配列を指定したセル位置から書き込む
    https://github.com/nkmk/python-snippets/blob/507a7fcb5b0a212d88015ffad77914c50509d4bc/notebook/openpyxl_example.py#L99-L116

    Args:
        sheet (sheet): Xlsxのsheetオブジェクト
        l_2d (list): 2次元配列
        start_row (int): 行(y)開始位置
        start_col (int): 列(x)開始位置
    """
    for y, row in enumerate(l_2d):
        for x, cell in enumerate(row):
            sheet.cell(
                row=start_row + y, column=start_col + x, value=l_2d[y][x]
            )



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': '.'}

packages = \
['src']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.1.2,<8.0.0', 'openpyxl>=3.0.4,<4.0.0']

entry_points = \
{'console_scripts': ['pyxl = src.main:cli']}

setup_kwargs = {
    'name': 'pyxl-cli',
    'version': '0.1.0',
    'description': 'openpyxl wrapper for cli use',
    'long_description': None,
    'author': 'wataru-kurashima',
    'author_email': 'wataru-kurashima@hands-lab.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
